@@ -1,5 +1,5 @@
 package Pod::Weaver::Plugin::Exec;
-$Pod::Weaver::Plugin::Exec::VERSION = '0.001001';
+$Pod::Weaver::Plugin::Exec::VERSION = '0.001002';
 # ABSTRACT: include output of commands in your pod
 
 use Moose;
@@ -15,7 +15,8 @@ package
    use Moose;
    with 'Pod::Elemental::Transformer';
 
-   use Capture::Tiny 'capture_stdout';
+   use Capture::Tiny 'capture';
+   use IPC::System::Simple 'system';
    use Moose::Autobox;
    use namespace::clean;
 
@@ -35,7 +36,17 @@ package
            and $para->children->[0]->isa('Pod::Elemental::Element::Pod5::Data');
 
          chomp(my $command = $para->children->[0]->content);
-         my $out = capture_stdout { system($command) };
+
+         local $@;
+         my ($out, $err, $ok) = capture {
+            eval { system $command; 1 };
+         };
+
+         chomp $out;
+         chomp $err;
+         die "Command '$command' failed\nSTDOUT: $out\nSTDERR: $err\n"
+            unless $ok;
+
          $out = join "\n", map " $_", split /\n/, $out;
 
          my $new_doc =
@@ -66,7 +77,7 @@ Pod::Weaver::Plugin::Exec - include output of commands in your pod
 
 =head1 VERSION
 
-version 0.001001
+version 0.001002
 
 =head1 SYNOPSIS
 
@@ -87,13 +98,27 @@ In the pod of one of your modules:
 This is a L<Pod::Weaver> plugin that will take the output of a command and
 insert it as literal data into the pod.
 
+=head1 PERL SUPPORT POLICY
+
+Because this module is geared towards helping release code, as opposed to
+helping run code, I only aim at supporting the last 3 releases of Perl.  So for
+example, at the time of writing that would be 5.20, 5.18, and 5.16.  As an
+author who is developing against Perl and using this to release modules, you can
+use either L<perlbrew|http://perlbrew.pl/> or
+L<plenv|https://github.com/tokuhirom/plenv> to get a more recent perl to release
+from.
+
+Don't bother sending patches to support older versions; I could probably support
+5.8 if I wanted, but this is more so that I can continue to use new perl
+features.
+
 =head1 AUTHOR
 
 Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
